==> config-api-0.3.8-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/ha_policy/replication_colocated/MasterConfiguration.java <==
package org.wildfly.swarm.config.messaging_activemq.server.ha_policy.replication_colocated;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
 */
@ResourceType("configuration")
@Implicit
public class MasterConfiguration {

	private String key;
	private Boolean checkForLiveServer;
	private String clusterName;
	private String groupName;

	public MasterConfiguration() {
		this.key = "master";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Whether to check the cluster for another server using the same server ID when starting up.
	 */
	@ModelNodeBinding(detypedName = "check-for-live-server")
	public Boolean checkForLiveServer() {
		return this.checkForLiveServer;
	}

	/**
	 * Whether to check the cluster for another server using the same server ID when starting up.
	 */
	@SuppressWarnings("unchecked")
	public MasterConfiguration checkForLiveServer(Boolean value) {
		this.checkForLiveServer = value;
		return (MasterConfiguration) this;
	}

	/**
	 * Name of the cluster used for replication.
	 */
	@ModelNodeBinding(detypedName = "cluster-name")
	public String clusterName() {
		return this.clusterName;
	}

	/**
	 * Name of the cluster used for replication.
	 */
	@SuppressWarnings("unchecked")
	public MasterConfiguration clusterName(String value) {
		this.clusterName = value;
		return (MasterConfiguration) this;
	}

	/**
	 * If set, backup servers will only pair with live servers with matching group-name.
	 */
	@ModelNodeBinding(detypedName = "group-name")
	public String groupName() {
		return this.groupName;
	}

	/**
	 * If set, backup servers will only pair with live servers with matching group-name.
	 */
	@SuppressWarnings("unchecked")
	public MasterConfiguration groupName(String value) {
		this.groupName = value;
		return (MasterConfiguration) this;
	}
}

==> config-api-0.3.10-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/ha_policy/replication_colocated/MasterConfiguration.java <==
package org.wildfly.swarm.config.messaging_activemq.server.ha_policy.replication_colocated;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * A messaging resource that allows you to configure High Availability for the ActiveMQ server (the value of ha-policy can be live-only, replication-master, replication-slave, or replication-colocated).
 */
@ResourceType("configuration")
@Implicit
public class MasterConfiguration<T extends MasterConfiguration> {

	private String key;
	private Boolean checkForLiveServer;
	private String clusterName;
	private String groupName;

	public MasterConfiguration() {
		this.key = "master";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Whether to check the cluster for another server using the same server ID when starting up.
	 */
	@ModelNodeBinding(detypedName = "check-for-live-server")
	public Boolean checkForLiveServer() {
		return this.checkForLiveServer;
	}

	/**
	 * Whether to check the cluster for another server using the same server ID when starting up.
	 */
	@SuppressWarnings("unchecked")
	public MasterConfiguration checkForLiveServer(Boolean value) {
		this.checkForLiveServer = value;
		return (MasterConfiguration) this;
	}

	/**
	 * Name of the cluster used for replication.
	 */
	@ModelNodeBinding(detypedName = "cluster-name")
	public String clusterName() {
		return this.clusterName;
	}

	/**
	 * Name of the cluster used for replication.
	 */
	@SuppressWarnings("unchecked")
	public MasterConfiguration clusterName(String value) {
		this.clusterName = value;
		return (MasterConfiguration) this;
	}

	/**
	 * If set, backup servers will only pair with live servers with matching group-name.
	 */
	@ModelNodeBinding(detypedName = "group-name")
	public String groupName() {
		return this.groupName;
	}

	/**
	 * If set, backup servers will only pair with live servers with matching group-name.
	 */
	@SuppressWarnings("unchecked")
	public MasterConfiguration groupName(String value) {
		this.groupName = value;
		return (MasterConfiguration) this;
	}
}
